==> addon-realtime-trigger-0.0.01-sources.jar: com/moengage/addon/trigger/DTConstants.java <==
package com.moengage.addon.trigger;

/**
 * @author Umang Chamaria
 */

interface DTConstants {

  String RESPONSE_ATTR_MINIMUM_DELAY_ACROSS_CAMPAIGNS = "min_delay_across_campaigns";

  String RESPONSE_ATTR_DND_START_TIME = "dnd_start_time";

  String RESPONSE_ATTR_DND_END_TIME = "dnd_end_time";

  String RESPONSE_ATTR_CAMPAIGN_LIST = "campaigns";

  String RESPONSE_ATTR_CAMPAIGN_ID = "campaign_id";

  String RESPONSE_ATTR_EVENT_NAME = "trigger_event_name";

  String RESPONSE_ATTR_FILTER = "filters";

  String RESPONSE_ATTR_FILTER_OPERATOR = "filter_operator";


  String RESPONSE_ATTR_CONDITION = "condition";

  String RESPONSE_ATTR_PAYLOAD = "payload";

  String RESPONSE_ATTR_EXPIRY = "expiry";

  String RESPONSE_ATTR_MAX_TIMES = "max_times";

  String RESPONSE_ATTR_SHOW_CAMPAIGN_AFTER = "show_delay";

  String RESPONSE_ATTR_MINIMUM_DELAY_BETWEEN = "min_delay_between_notifications";

  String RESPONSE_ATTR_MAXIMUM_SYNC_DELAY = "max_sync_delay";

  String RESPONSE_ATTR_SHOULD_SUPPORT_OFFLINE = "should_support_offline";

  String RESPONSE_ATTR_SHOULD_IGNORE_DND = "should_ignore_dnd";

  String RESPONSE_ATTR_CAMPAIGN_TYPE = "type";

  String RESPONSE_ATTR_PRIORITY = "priority";

  String RESPONSE_ATTR_STATUS = "status";

  String RESPONSE_ATTR_LAST_UPDATED_TIME = "last_updated";

  String RESPONSE_ATTR_USER_IN_SEGMENT = "user_in_segment";

  String RESPONSE_ATTR_SHOW_NOTIFICATION = "show_notification";

  String RESPONSE_ATTR_USER_NOT_FOUND = "user_not_found";

  String CAMPAIGN_STATUS_ACTIVE = "active";

  String CAMPAIGN_STATUS_PAUSE = "pause";

  String CAMPAIGN_STATUS_STOPPED = "stopped";

  String CAMPAIGN_STATUS_EXPIRED = "expired";

  String ENDPOINT_SYNC_DT = "/v1/sdk-trigger/sync";

  String ENDPOINT_USER_IN_SEGMENT = "/v1/sdk-trigger/user-in-segment";

  String REQUEST_ATTR_LAST_SYNC_TIME = "last_sync_time";

  String REQUEST_ATTR_CAMPAIGN_IDS = "campaign_ids";

  String ACTION_SYNC_MESSAGES = "ACTION_SYNC_MESSAGES";

  String ACTION_SHOW_NOTIFICATION = "ACTION_SHOW_NOTIFICATION";

  String EXTRA_SHOW_NOTIFICATION = "NOTIFICATION_EXTRA";

  String EXTRA_NOTIFICATION_PAYLOAD = "NOTIFICATION_PAYLOAD";

  int REQ_CODE_FETCH_TRIGGERS = 10002;

  int MESSAGE_SYNC_JOB_ID = 99912;

  String CAMPAIGN_TYPE_GENERAL = "general";

  String FILTER_OPERATOR_AND = "and";

  String FILTER_OPERATOR_OR = "or";

  String EXTRA_ATTR_OFFLINE = "isOffline";
}

==> addon-realtime-trigger-2.2.00-sources.jar: com/moengage/addon/trigger/DTConstants.java <==
package com.moengage.addon.trigger;

/**
 * @author Umang Chamaria
 */

interface DTConstants {

  String RESPONSE_ATTR_MINIMUM_DELAY_ACROSS_CAMPAIGNS = "min_delay_across_campaigns";

  String RESPONSE_ATTR_DND_START_TIME = "dnd_start_time";

  String RESPONSE_ATTR_DND_END_TIME = "dnd_end_time";

  String RESPONSE_ATTR_CAMPAIGN_LIST = "campaigns";

  String RESPONSE_ATTR_CAMPAIGN_ID = "campaign_id";

  String RESPONSE_ATTR_EVENT_NAME = "trigger_event_name";

  String RESPONSE_ATTR_FILTER = "filters";

  String RESPONSE_ATTR_FILTER_OPERATOR = "filter_operator";


  String RESPONSE_ATTR_CONDITION = "condition";

  String RESPONSE_ATTR_PAYLOAD = "payload";

  String RESPONSE_ATTR_EXPIRY = "expiry";

  String RESPONSE_ATTR_MAX_TIMES = "max_times";

  String RESPONSE_ATTR_SHOW_CAMPAIGN_AFTER = "show_delay";

  String RESPONSE_ATTR_MINIMUM_DELAY_BETWEEN = "min_delay_between_notifications";

  String RESPONSE_ATTR_MAXIMUM_SYNC_DELAY = "max_sync_delay";

  String RESPONSE_ATTR_SHOULD_SUPPORT_OFFLINE = "should_support_offline";

  String RESPONSE_ATTR_SHOULD_IGNORE_DND = "should_ignore_dnd";

  String RESPONSE_ATTR_CAMPAIGN_TYPE = "type";

  String RESPONSE_ATTR_PRIORITY = "priority";

  String RESPONSE_ATTR_STATUS = "status";

  String RESPONSE_ATTR_LAST_UPDATED_TIME = "last_updated";

  String RESPONSE_ATTR_USER_IN_SEGMENT = "user_in_segment";

  String RESPONSE_ATTR_SHOW_NOTIFICATION = "show_notification";

  String RESPONSE_ATTR_USER_NOT_FOUND = "user_not_found";

  String CAMPAIGN_STATUS_ACTIVE = "active";

  String CAMPAIGN_STATUS_PAUSE = "pause";

  String CAMPAIGN_STATUS_STOPPED = "stopped";

  String CAMPAIGN_STATUS_EXPIRED = "expired";

  String ENDPOINT_SYNC_DT = "/v1/sdk-trigger/sync";

  String ENDPOINT_USER_IN_SEGMENT = "/v1/sdk-trigger/user-in-segment";

  String REQUEST_ATTR_LAST_SYNC_TIME = "last_sync_time";

  String REQUEST_ATTR_CAMPAIGN_IDS = "campaign_ids";

  String ACTION_SYNC_MESSAGES = "ACTION_SYNC_MESSAGES";

  String ACTION_SHOW_NOTIFICATION = "ACTION_SHOW_NOTIFICATION";

  String EXTRA_SHOW_NOTIFICATION = "NOTIFICATION_EXTRA";

  String EXTRA_NOTIFICATION_PAYLOAD = "NOTIFICATION_PAYLOAD";

  int REQ_CODE_FETCH_TRIGGERS = 10002;

  int DT_SYNC_JOB_ID = 99912;

  String CAMPAIGN_TYPE_GENERAL = "general";

  String FILTER_OPERATOR_AND = "and";

  String FILTER_OPERATOR_OR = "or";

  String EXTRA_ATTR_OFFLINE = "isOffline";
}
